function InfoCallback(event)
% InfoCallback - Callback called by modelit.webserver.Server object for generating a
% simple HTML response.
%
% CALL:
%     InfoCallback(event)
%
% INPUT:
%     event: <modelit.webserver.HttpExchange>
%       with the request data and methods to generate a response.
%
% OUTPUT:
%     No output, a response with a simple HTML string with the current time is returned.
%
% EXAMPLE:
%  server = modelit.web.server.Server(8081, @InfoCallback).start() 
%
%  % Open a webbrowser and type: http://localhost:8081 in the address bar
%  % Now a string with the current time appears in the browser.

%   Copyright 2020 Modelit, www.modelit.nl

event.addResponseHeader('Content-Type', 'text/html', 'Access-Control-Allow-Origin', '*'); % cors
event.send(200, sprintf('<html><p>%s</p></html>', datestr(now)))
