function server = demo_MEWT(host, port, show)
% demo_MEWT - Server with examples of callbacks. The server listens to
% port in the range 8082 and creates a number of callbacks
% 
% CALL:
%     httpsServerExample
% 
% INPUT:
%     no input required
% 
% OUTPUT:
%     server: <modelit.web.server.Server>
%       a server listening to the port 8082
%       localhost:port/ ==> InfoCallback
%       localhost:port/html ==> HTMLCallback
%       localhost:port/xml ==> XMLCallback
%       localhost:port/json ==> JSONCallback
%       localhost:port/pdf ==> PDFCallback
%       localhost:port/image ==> ImageCallback
%       localhost:port/figure ==> FigureCallback
%       localhost:port/authentication ==> AuthenticationCallback (log in with username:
%       user, password: 1234)
%       localhost:port/html2 ==> HTMLCallback, credentials required
% 
% NOTE:
%     this example

% Use generateSelfSignedCertificate to make a keystore

% Server listens to http request on port 8082
disp('Run demo for Modelit Embedded Webserver (MEWT)')

% Input arguments for Docker-File and Docker-compose file.
if nargin < 1
    host = 'localhost';
end
if nargin < 2
    port = 8082;
end
if ischar(port)
    port = str2num(port);
end

server = modelit.web.server.Server(port,[],'hostname',host);
urlroot=sprintf('localhost:%d',port);

dprintf('Launching example "InfoCallback" ...')
server.addContext('/',@InfoCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/',urlroot))

dprintf('Launching example "HTMLCallback" ...')
server.addContext('/html',@HTMLCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/html',urlroot))

dprintf('Launching example "XMLCallback" ...')
server.addContext('/xml',@XMLCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/xml',urlroot))

dprintf('Launching example "JSONCallback" ...')
server.addContext('/json',@JSONCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/json',urlroot))

dprintf('Launching example "PDFCallback" ...')
server.addContext('/pdf',@PDFCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/pdf',urlroot))

dprintf('Launching example "ImageCallback" ...')
server.addContext('/image',@ImageCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/image',urlroot))

dprintf('Launching example "FigureCallback" ...')
server.addContext('/figure',@FigureCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/figure',urlroot))

dprintf('Launching example "TemperatureConversionSimpleCallback" ...')
server.addContext(sprintf('/%s','temperatureconversionsimple'),@TemperatureConversionSimpleCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/%s',urlroot, 'temperatureconversionsimple'))

dprintf('Launching example "TemperatureConversionCallback" ...')
server.addContext(sprintf('/%s','temperatureconversion'),@TemperatureConversionCallback);
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/%s',urlroot, 'temperatureconversion'))

dprintf('Launching example "AuthenticationCallback" ...')
server.addContext('/authentication',@AuthenticationCallback,'user','1234');
dprintf('To verify this example, open the url "%s" in your web browser. Hint: username="user", password="1234".',...
    sprintf('%s/authentication',urlroot))

dprintf('Launching example "HTMLCallback with credentials" ...')
server.addContext('/html2',@HTMLCallback,'user','1234');
dprintf('To verify this example, open the url "%s" in your web browser',...
    sprintf('%s/html2',urlroot))

dprintf('Launching example "remoteCallback" ...')
server.addContext('/sort',remoteCallback('sort'));
dprintf('To verify this example, start a SECOND Matlab session. Then issue commands:');
dprintf('    fp_sort = remoteFunction(''http://%s/sort'',@sort)',urlroot);
disp('    [B,I] = fp_sort(10:-1:1)');

% start listening
server.start;

if nargin < 3
    HWIN=figure('Name',sprintf('Server is active on port %d',port),'DeleteFcn',@(o,e)stopserver(server));
    h=uicontrol(HWIN,'style','pushbutton','str','Stop server','units','norm','position',[.1,.4,.8,.2],'callback',@(o,e)delete(HWIN));
end

function stopserver(server)
disp('Stopping server...')
server.stop;
disp('The server has been stopped.')




