function monitorprogress
% monitorprogress - Example of progress monitoring of an HTTP request.
%
% CALL:
%   monitorprogress
%
% INPUT:
%  No input required
%
% OUTPUT:
%  No output

% Define the properties of the HTTP request.
% Use httpbin.org for testing.
% If an HTTP GET request is sent to: The https://httpbin.org/bytes/102400
% 102400 random bytes are returned from the httpbin server.
METHOD = 'GET';
URL = 'https://httpbin.org/bytes/102400';

% Initialize the HTTP request
request = modelit.web.client.HttpRequest(METHOD, URL);
% Set the callback to be executed when the request has finished
request.setCompletedCallback(@completedCallback);
% Set the callback to process the
request.setProgressUpdatedCallback(@progressUpdatedCallback);
request.send;

%__________________________________________________________________________
function completedCallback(obj)
% completedCallback - Callback triggered when the request has completed.
%
% CALL:
%   completedCallback(obj)
%
% INPUT:
%   obj: <modelit.web.client.HttpResponse>
%     The response from the server
%
% OUTPUT:
%  No output

fprintf('request -> %d (%d bytes received)\n', obj.getResponseCode(), length(obj.data));

%__________________________________________________________________________
function progressUpdatedCallback(obj, event)
% progressUpdatedCallback -
%
% CALL:
%   progressUpdatedCallback(obj, event)
%
% INPUT:
%  obj: <nl.modelit.web.client.HttpRequest>
%    Java object with the HTTP request
%  event: <nl.modelit.web.client.ProgressEvent>
%    Contains information about the progress
%
% OUTPUT:
%  No output

% Get the progress in procent from the
progress = event.getProgress();

fprintf('%d%% completed\n', round(progress));