%  fig2image - convert Matlab figure to java image.   
%   
%  CALL:   
%   [image, bufferedimage] = fig2image(fig,insets)   
%   
%  INPUT:   
%   fig: <figure>   
%     optional, handle of figure to convert to a java image   
%     default value: gcf   
%   insets: <number[4]>   
%      insets=[left bottom right top]   
%      optional arguments, defaults to [0 0 0 0]   
%   
%  OUTPUT:   
%   image: <java.awt.Image>   
%   bufferedimage: <java.awt.image.BufferedImage>   
%     An image with an accessible buffer with image data   
%   
%  EXAMPLE:   
%      hfig=figure;   
%      plot(1:10);   
%      [img, bimg] = fig2image(hfig);   
%      html = image2html(bimg, 'png');   
%      delete(hfig)   
%      disp(html)   
%   
%  APPROACH:   
%   print the figure to a temporary .png file using Matlab's print method   
%   get bufferedimage with javax.imageio.ImageIO and make an image from the   
%   bufferedimage with java.awt.Toolkit.   
%   
%    Copyright 2006-2019 Modelit, www.modelit.nl   
%   
%  See also: print, im2java, image2html   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
